#
# spec file for package gr-iqbal
#
# Copyright (c) 2020-2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libgnuradio-iqbalance
%define soname 3_9_0

Name:           gr-iqbal
Version:        0.39.0git20210108
Release:        1.12
Summary:        GNU Radio I/Q balancing
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://git.osmocom.org/gr-iqbal/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gnuradio-devel >= 3.9.0
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libosmo-dsp-devel
BuildRequires:  libunwind-devel
BuildRequires:  orc
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pybind11-devel
%if 0%{?suse_version} <= 1500
BuildRequires:  python3-six
%endif

%description
I/Q balancing for GNU Radio

%package -n %{libname}%{soname}
Summary:        Libraries for gr-iqbal
Group:          System/Libraries

%description -n %{libname}%{soname}
I/Q balancing for GNU Radio

%package -n %{name}-grc
Summary:        GRC blocks for gr-iqbal
Group:          Productivity/Hamradio/Other
Requires:       %{libname}%{soname} = %{version}
# GRC yaml files were in the library package previously
Conflicts:      libgnuradio-iqbalance0_37_2git
BuildArch:      noarch

%description -n %{name}-grc
GNU Radio Companion (GRC) definitions for the
gr-iqbal I/Q balancing block.

%package -n python3-gr-iqbal
Summary:        Python bindings for gr-iqbal
Group:          Development/Libraries/Python
Requires:       %{libname}%{soname} = %{version}

%description -n python3-gr-iqbal
The Python Bindings for gr-iqbal.

%package -n %{libname}-devel
Summary:        Development files for gr-iqbal
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soname} = %{version}
Conflicts:      libgnuradio-iqbalance <= 0.37.2+git.20151121

%description -n %{libname}-devel
Library headers for gr-iqbal, I/Q balancing for GNU Radio

%package devel-doc
Summary:        Documentation for gr-iqbal
Group:          Documentation/HTML
Recommends:     libgnuradio-iqbalance-devel = %{version}
BuildArch:      noarch
Obsoletes:      %{name}-doc

%description devel-doc
Documentation for gr-iqbal module for GNU Radio.

%prep
%setup -q -n %{name}

%build
%cmake \
  -Wno-dev
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}/%{_datadir}/doc/gr-iqbalance %{buildroot}%{_docdir}/

%fdupes %{buildroot}%{python3_sitearch}

%post -n %{libname}%{soname} -p /sbin/ldconfig
%postun -n %{libname}%{soname} -p /sbin/ldconfig

%files -n %{libname}%{soname}
%doc AUTHORS
%license COPYING
%{_libdir}/%{libname}.so.*

%files -n %{name}-grc
%{_datadir}/gnuradio

%files -n python3-gr-iqbal
%{python3_sitearch}/gnuradio/iqbalance

%files -n %{libname}-devel
%{_includedir}/gnuradio/iqbalance
%{_libdir}/%{libname}.so
%{_libdir}/cmake/gnuradio/gnuradio-iqbalance*

%files devel-doc
%dir %{_docdir}/gr-iqbalance
%{_docdir}/gr-iqbalance/html
%{_docdir}/gr-iqbalance/xml

%changelog
* Sun Feb 27 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- fix grc subpackage dependency
* Sun Feb 20 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- restore old name of doc package
- remove outdated provides
* Wed Sep 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 0.39.0 snapshot 20210108
- builds with GNU Radio 3.9
* Tue Jan 12 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to release 0.38.2
- Patch 0001-boost-qualify-placeholders-with-their-full-namespace.patch
  removed (applied upstream)
* Mon Sep 21 2020 Martin Hauke <mardnh@gmx.de>
- Add patch to fix build against boost >= 1.73:
  * 0001-boost-qualify-placeholders-with-their-full-namespace.patch
* Tue Feb 11 2020 Martin Pluskal <mpluskal@suse.com>
- Split GRC block definitons to separate package - based on changes
  suggested by Stefan Bruens
* Sun Feb  2 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to release 0.38.1
* Mon Nov  4 2019 Martin Pluskal <mpluskal@suse.com>
- Fix name of python subpackage
- Use more of modern cmake macros
* Sun Nov  3 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add explicit conflicts to old libgnuradio-iqbalance package,
  to make installcheck happy.
* Fri Nov  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix some packaging bugs:
  + devel subpackage Provides unversioned library file, fixes file
    conflict with old package versions
  + Do not require non-existing package from devel-doc subpackage
* Fri Nov  1 2019 stefan.bruens@rwth-aachen.de
- Update to version 0.37.2+git.20191101:
  * Convert GRC xml to yaml
* Sun Sep 29 2019 stefan.bruens@rwth-aachen.de
- Update to version 0.37.2+git.20190929:
  * Port to gnuradio 3.8
- Cleanup spec file
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Adjust RPM groups.
- Remove useless ldconfig call from python-gr-iqbal.
* Sat Dec  9 2017 wk@ire.pw.edu.pl
- improve boost dependency
* Sun Apr 23 2017 mardnh@gmx.de
- Add _service file
- Use package-meta for tar_scm service and add git-core
  to BuildRequires
- Use some specfiles variables to ease maintenance
* Wed Mar  8 2017 mpluskal@suse.com
- Cleanup with spec-cleaner
* Fri Sep  5 2014 dl8fcl@darc.de
- update to version 0.37.2_2_g44ab02f
* Wed Aug 20 2014 dl8fcl@darc.de
- change of requires in spec file. libosmodsp > libosmo-dsp
* Sun Sep 22 2013 dl8fcl@darc.de
- update to version 0.37.1.4
* Wed Sep 11 2013 dl8fcl@darc.de
- update to version 0.37.1.3
  hack to make "float complex" works on newer GCC
* Sat Aug 10 2013 dl8fcl@darc.de
- import into build service
